@@ -26,7 +26,6 @@
 #include <KLocalizedString>
 #include <KXmlGuiWindow>
 #include <QAction>
-#include <QDebug>
 #include <QGraphicsOpacityEffect>
 #include <QLabel>
 #include <QMenu>
@@ -34,7 +33,6 @@
 #include <QQmlEngine>
 #include <QQuickItem>
 #include <QQuickWidget>
-#include <QStandardItemModel>
 #include <QStandardPaths>
 
 FocusHackWidget::FocusHackWidget(QWidget *parent)
@@ -740,8 +738,8 @@ bool SidebarMode::eventFilter(QObject *watched, QEvent *event)
     switch (event->type()) {
     case QEvent::KeyPress: {
         // allow tab navigation inside the qquickwidget
-        QKeyEvent *ke = static_cast<QKeyEvent *>(event);
-        QQuickWidget *qqw = static_cast<QQuickWidget *>(watched);
+        auto ke = static_cast<QKeyEvent *>(event);
+        auto qqw = qobject_cast<QQuickWidget *>(watched);
         if (ke->key() == Qt::Key_Tab || ke->key() == Qt::Key_Backtab) {
             QCoreApplication::sendEvent(qqw->quickWindow(), event);
             return true;
