@@ -50,21 +50,20 @@ BaseMode::BaseMode(QObject *parent, const QVariantList &args)
     }
 }
 
-BaseMode::~BaseMode()
-{
-    delete d;
-}
-
-void BaseMode::init(const KPluginMetaData &metaData)
+void BaseMode::init()
 {
     d->rootItem = BaseData::instance()->menuItem();
     d->homeItem = BaseData::instance()->homeItem();
-    d->metaData = metaData;
-    d->config = BaseData::instance()->configGroup(metaData.pluginId());
+    d->config = BaseData::instance()->configGroup(QStringLiteral("systemsettings_sidebar_mode"));
     initEvent();
     connect(moduleView(), &ModuleView::moduleChanged, this, &BaseMode::viewChanged);
 }
 
+BaseMode::~BaseMode()
+{
+    delete d;
+}
+
 void BaseMode::initEvent()
 {
 }
@@ -74,11 +73,6 @@ QWidget *BaseMode::mainWidget()
     return nullptr;
 }
 
-KAboutData *BaseMode::aboutData()
-{
-    return nullptr;
-}
-
 BaseMode::ApplicationMode BaseMode::applicationMode() const
 {
     return d->applicationMode;
@@ -119,26 +113,20 @@ QStringList BaseMode::startupModuleArgs() const
     return d->startupModuleArgs;
 }
 
-void BaseMode::searchChanged(const QString &text)
+void BaseMode::searchChanged(const QString & /*text*/)
 {
-    Q_UNUSED(text);
 }
 
 void BaseMode::saveState()
 {
 }
 
-void BaseMode::leaveModuleView()
-{
-}
-
 void BaseMode::giveFocus()
 {
 }
 
-void BaseMode::addConfiguration(KConfigDialog *config)
+void BaseMode::addConfiguration(KConfigDialog * /*config**/)
 {
-    Q_UNUSED(config);
 }
 
 void BaseMode::loadConfiguration()
@@ -166,7 +154,7 @@ KConfigGroup &BaseMode::config() const
 
 QList<QAbstractItemView *> BaseMode::views() const
 {
-    return QList<QAbstractItemView *>();
+    return {};
 }
 
 bool BaseMode::defaultsIndicatorsVisible() const
@@ -177,3 +165,5 @@ bool BaseMode::defaultsIndicatorsVisible() const
 void BaseMode::toggleDefaultsIndicatorsVisibility()
 {
 }
+
+#include "moc_BaseMode.cpp"
