@@ -8,7 +8,6 @@
 #include "MenuModel.h"
 
 #include "MenuItem.h"
-#include <KCModuleInfo>
 #include <KCategorizedSortFilterProxyModel>
 #include <QIcon>
 
@@ -47,9 +46,8 @@ QHash<int, QByteArray> MenuModel::roleNames() const
     return names;
 }
 
-int MenuModel::columnCount(const QModelIndex &parent) const
+int MenuModel::columnCount(const QModelIndex & /*parent*/) const
 {
-    Q_UNUSED(parent);
     return 1;
 }
 
@@ -66,13 +64,12 @@ int MenuModel::rowCount(const QModelIndex &parent) const
 
 QVariant MenuModel::data(const QModelIndex &index, int role) const
 {
-    MenuItem *mi = nullptr;
     QVariant theData;
     if (!index.isValid()) {
-        return QVariant();
+        return {};
     }
 
-    mi = static_cast<MenuItem *>(index.internalPointer());
+    auto mi = static_cast<MenuItem *>(index.internalPointer());
     switch (role) {
     case Qt::DisplayRole:
         theData.setValue(mi->name());
@@ -109,7 +106,7 @@ QVariant MenuModel::data(const QModelIndex &index, int role) const
         theData.setValue(mi->keywords().join(QString()));
         break;
     case MenuModel::UserSortRole:
-        //Category owners are always before everything else, regardless of weight
+        // Category owners are always before everything else, regardless of weight
         if (mi->isCategoryOwner()) {
             theData.setValue(QStringLiteral("%1").arg(QString::number(mi->weight()), 5, QLatin1Char('0')));
         } else {
@@ -164,7 +161,7 @@ Qt::ItemFlags MenuModel::flags(const QModelIndex &index) const
 QModelIndex MenuModel::index(int row, int column, const QModelIndex &parent) const
 {
     if (!hasIndex(row, column, parent)) {
-        return QModelIndex();
+        return {};
     }
 
     MenuItem *parentItem;
@@ -178,15 +175,15 @@ QModelIndex MenuModel::index(int row, int column, const QModelIndex &parent) con
     if (childItem) {
         return createIndex(row, column, childItem);
     } else {
-        return QModelIndex();
+        return {};
     }
 }
 
 QModelIndex MenuModel::parent(const QModelIndex &index) const
 {
-    MenuItem *childItem = static_cast<MenuItem *>(index.internalPointer());
+    auto childItem = static_cast<MenuItem *>(index.internalPointer());
     if (!childItem) {
-        return QModelIndex();
+        return {};
     }
 
     MenuItem *parent = parentItem(childItem);
@@ -198,7 +195,7 @@ QModelIndex MenuModel::parent(const QModelIndex &index) const
     }
 
     if (parent == d->rootItem) {
-        return QModelIndex();
+        return {};
     }
     return createIndex(childRow, 0, parent);
 }
@@ -229,13 +226,13 @@ QModelIndex MenuModel::indexForItem(MenuItem *item) const
     MenuItem *parent = parentItem(item);
 
     if (!parent) {
-        return QModelIndex();
+        return {};
     }
 
     const int row = childrenList(parent).indexOf(item);
 
     if (row < 0) {
-        return QModelIndex();
+        return {};
     }
 
     return createIndex(row, 0, item);
@@ -258,3 +255,5 @@ void MenuModel::removeException(MenuItem *exception)
 {
     d->exceptions.removeAll(exception);
 }
+
+#include "moc_MenuModel.cpp"
